#[non_exhaustive]pub enum State {
Show 14 variants
Unspecified,
ApprovalAwaited,
Denied,
Scheduled,
Activating,
Active,
ActivationFailed,
Expired,
Revoking,
Revoked,
Ended,
Withdrawing,
Withdrawn,
UnknownValue(UnknownValue),
}Expand description
Different states a grant can be in.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Unspecified state. This value is never returned by the server.
ApprovalAwaited
The entitlement had an approval workflow configured and this grant is waiting for the workflow to complete.
Denied
The approval workflow completed with a denied result. No access is granted for this grant. This is a terminal state.
Scheduled
The approval workflow completed successfully with an approved result or none was configured. Access is provided at an appropriate time.
Activating
Access is being given.
Active
Access was successfully given and is currently active.
ActivationFailed
The system could not give access due to a non-retriable error. This is a terminal state.
Expired
Expired after waiting for the approval workflow to complete. This is a terminal state.
Revoking
Access is being revoked.
Revoked
Access was revoked by a user. This is a terminal state.
Ended
System took back access as the requested duration was over. This is a terminal state.
Withdrawing
Access is being withdrawn.
Withdrawn
Grant was withdrawn by the grant owner. This is a terminal state.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using State::value or State::name.
Implementations