#[non_exhaustive]pub enum Justification {
UnstructuredJustification(String),
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
UnstructuredJustification(String)
A free form textual justification. The system only ensures that this is not empty. No other kind of validation is performed on the string.