#[non_exhaustive]pub struct CreateEntitlementRequest {
pub parent: String,
pub entitlement_id: String,
pub entitlement: Option<Entitlement>,
pub request_id: String,
/* private fields */
}Expand description
Message for creating an entitlement.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. Name of the parent resource for the entitlement. Possible formats:
organizations/{organization-number}/locations/{region}folders/{folder-number}/locations/{region}projects/{project-id|project-number}/locations/{region}
entitlement_id: StringRequired. The ID to use for this entitlement. This becomes the last part of the resource name.
This value should be 4-63 characters in length, and valid characters are “[a-z]”, “[0-9]”, and “-”. The first character should be from [a-z].
This value should be unique among all other entitlements under the
specified parent.
entitlement: Option<Entitlement>Required. The resource being created
request_id: StringOptional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server knows to ignore the request if it has already been completed. The server guarantees this for at least 60 minutes after the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, ignores the second request and returns the previous operation’s response. This prevents clients from accidentally creating duplicate entitlements.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
Implementations
Sourceimpl CreateEntitlementRequest
impl CreateEntitlementRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_entitlement_id<T: Into<String>>(self, v: T) -> Self
pub fn set_entitlement_id<T: Into<String>>(self, v: T) -> Self
Sets the value of entitlement_id.
Example
let x = CreateEntitlementRequest::new().set_entitlement_id("example");Sourcepub fn set_entitlement<T>(self, v: T) -> Selfwhere
T: Into<Entitlement>,
pub fn set_entitlement<T>(self, v: T) -> Selfwhere
T: Into<Entitlement>,
Sets the value of entitlement.
Example
use google_cloud_privilegedaccessmanager_v1::model::Entitlement;
let x = CreateEntitlementRequest::new().set_entitlement(Entitlement::default()/* use setters */);Sourcepub fn set_or_clear_entitlement<T>(self, v: Option<T>) -> Selfwhere
T: Into<Entitlement>,
pub fn set_or_clear_entitlement<T>(self, v: Option<T>) -> Selfwhere
T: Into<Entitlement>,
Sets or clears the value of entitlement.
Example
use google_cloud_privilegedaccessmanager_v1::model::Entitlement;
let x = CreateEntitlementRequest::new().set_or_clear_entitlement(Some(Entitlement::default()/* use setters */));
let x = CreateEntitlementRequest::new().set_or_clear_entitlement(None::<Entitlement>);Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = CreateEntitlementRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for CreateEntitlementRequest
impl Clone for CreateEntitlementRequest
Sourcefn clone(&self) -> CreateEntitlementRequest
fn clone(&self) -> CreateEntitlementRequest
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more