#[non_exhaustive]pub struct CreateGrantRequest {
pub parent: String,
pub grant: Option<Grant>,
pub request_id: String,
/* private fields */
}Expand description
Message for creating a grant
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. Name of the parent entitlement for which this grant is being requested.
grant: Option<Grant>Required. The resource being created.
request_id: StringOptional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server knows to ignore the request if it has already been completed. The server guarantees this for at least 60 minutes after the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, ignores the second request. This prevents clients from accidentally creating duplicate grants.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
Implementations
Sourceimpl CreateGrantRequest
impl CreateGrantRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_or_clear_grant<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_grant<T>(self, v: Option<T>) -> Self
Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = CreateGrantRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for CreateGrantRequest
impl Clone for CreateGrantRequest
Sourcefn clone(&self) -> CreateGrantRequest
fn clone(&self) -> CreateGrantRequest
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more