#[non_exhaustive]pub struct Justification {
pub justification: Option<Justification>,
/* private fields */
}Expand description
Justification represents a justification for requesting access.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.justification: Option<Justification>Implementations
Sourceimpl Justification
impl Justification
Sourcepub fn set_justification<T: Into<Option<Justification>>>(self, v: T) -> Self
pub fn set_justification<T: Into<Option<Justification>>>(self, v: T) -> Self
Sets the value of justification.
Note that all the setters affecting justification are mutually
exclusive.
Example
ⓘ
use google_cloud_privilegedaccessmanager_v1::model::justification::Justification as JustificationOneOf;
let x = Justification::new().set_justification(Some(JustificationOneOf::UnstructuredJustification("example".to_string())));Sourcepub fn unstructured_justification(&self) -> Option<&String>
pub fn unstructured_justification(&self) -> Option<&String>
The value of justification
if it holds a UnstructuredJustification, None if the field is not set or
holds a different branch.
Sourcepub fn set_unstructured_justification<T: Into<String>>(self, v: T) -> Self
pub fn set_unstructured_justification<T: Into<String>>(self, v: T) -> Self
Sets the value of justification
to hold a UnstructuredJustification.
Note that all the setters affecting justification are
mutually exclusive.
Example
ⓘ
let x = Justification::new().set_unstructured_justification("example");
assert!(x.unstructured_justification().is_some());Trait Implementations
Sourceimpl Clone for Justification
impl Clone for Justification
Sourcefn clone(&self) -> Justification
fn clone(&self) -> Justification
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Justification
impl Debug for Justification
Sourceimpl Default for Justification
impl Default for Justification
Sourcefn default() -> Justification
fn default() -> Justification
Returns the “default value” for a type. Read more
Sourceimpl Message for Justification
impl Message for Justification
Sourceimpl PartialEq for Justification
impl PartialEq for Justification
impl StructuralPartialEq for Justification