#[non_exhaustive]pub struct PrivilegedAccess {
pub access_type: Option<AccessType>,
/* private fields */
}Expand description
Privileged access that this service can be used to gate.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.access_type: Option<AccessType>Implementations
Sourceimpl PrivilegedAccess
impl PrivilegedAccess
Sourcepub fn set_access_type<T: Into<Option<AccessType>>>(self, v: T) -> Self
pub fn set_access_type<T: Into<Option<AccessType>>>(self, v: T) -> Self
Sets the value of access_type.
Note that all the setters affecting access_type are mutually
exclusive.
Example
ⓘ
use google_cloud_privilegedaccessmanager_v1::model::privileged_access::GcpIamAccess;
let x = PrivilegedAccess::new().set_access_type(Some(
google_cloud_privilegedaccessmanager_v1::model::privileged_access::AccessType::GcpIamAccess(GcpIamAccess::default().into())));Sourcepub fn gcp_iam_access(&self) -> Option<&Box<GcpIamAccess>>
pub fn gcp_iam_access(&self) -> Option<&Box<GcpIamAccess>>
The value of access_type
if it holds a GcpIamAccess, None if the field is not set or
holds a different branch.
Sourcepub fn set_gcp_iam_access<T: Into<Box<GcpIamAccess>>>(self, v: T) -> Self
pub fn set_gcp_iam_access<T: Into<Box<GcpIamAccess>>>(self, v: T) -> Self
Sets the value of access_type
to hold a GcpIamAccess.
Note that all the setters affecting access_type are
mutually exclusive.
Example
ⓘ
use google_cloud_privilegedaccessmanager_v1::model::privileged_access::GcpIamAccess;
let x = PrivilegedAccess::new().set_gcp_iam_access(GcpIamAccess::default()/* use setters */);
assert!(x.gcp_iam_access().is_some());Trait Implementations
Sourceimpl Clone for PrivilegedAccess
impl Clone for PrivilegedAccess
Sourcefn clone(&self) -> PrivilegedAccess
fn clone(&self) -> PrivilegedAccess
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PrivilegedAccess
impl Debug for PrivilegedAccess
Sourceimpl Default for PrivilegedAccess
impl Default for PrivilegedAccess
Sourcefn default() -> PrivilegedAccess
fn default() -> PrivilegedAccess
Returns the “default value” for a type. Read more
Sourceimpl Message for PrivilegedAccess
impl Message for PrivilegedAccess
Sourceimpl PartialEq for PrivilegedAccess
impl PartialEq for PrivilegedAccess
impl StructuralPartialEq for PrivilegedAccess