#[non_exhaustive]pub struct SearchEntitlementsRequest {
pub parent: String,
pub caller_access_type: CallerAccessType,
pub filter: String,
pub page_size: i32,
pub page_token: String,
/* private fields */
}Expand description
Request message for SearchEntitlements method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent which owns the entitlement resources.
caller_access_type: CallerAccessTypeRequired. Only entitlements where the calling user has this access are returned.
filter: StringOptional. Only entitlements matching this filter are returned in the response.
page_size: i32Optional. Requested page size. The server may return fewer items than requested. If unspecified, the server picks an appropriate default.
page_token: StringOptional. A token identifying a page of results the server should return.
Implementations
Sourceimpl SearchEntitlementsRequest
impl SearchEntitlementsRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_caller_access_type<T: Into<CallerAccessType>>(self, v: T) -> Self
pub fn set_caller_access_type<T: Into<CallerAccessType>>(self, v: T) -> Self
Sets the value of caller_access_type.
Example
ⓘ
use google_cloud_privilegedaccessmanager_v1::model::search_entitlements_request::CallerAccessType;
let x0 = SearchEntitlementsRequest::new().set_caller_access_type(CallerAccessType::GrantRequester);
let x1 = SearchEntitlementsRequest::new().set_caller_access_type(CallerAccessType::GrantApprover);Sourcepub fn set_filter<T: Into<String>>(self, v: T) -> Self
pub fn set_filter<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
ⓘ
let x = SearchEntitlementsRequest::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for SearchEntitlementsRequest
impl Clone for SearchEntitlementsRequest
Sourcefn clone(&self) -> SearchEntitlementsRequest
fn clone(&self) -> SearchEntitlementsRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SearchEntitlementsRequest
impl Debug for SearchEntitlementsRequest
Sourceimpl Default for SearchEntitlementsRequest
impl Default for SearchEntitlementsRequest
Sourcefn default() -> SearchEntitlementsRequest
fn default() -> SearchEntitlementsRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for SearchEntitlementsRequest
impl Message for SearchEntitlementsRequest
impl StructuralPartialEq for SearchEntitlementsRequest