#[non_exhaustive]pub struct SearchGrantsRequest {
pub parent: String,
pub caller_relationship: CallerRelationshipType,
pub filter: String,
pub page_size: i32,
pub page_token: String,
/* private fields */
}Expand description
Request message for SearchGrants method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent which owns the grant resources.
caller_relationship: CallerRelationshipTypeRequired. Only grants which the caller is related to by this relationship are returned in the response.
filter: StringOptional. Only grants matching this filter are returned in the response.
page_size: i32Optional. Requested page size. The server may return fewer items than requested. If unspecified, server picks an appropriate default.
page_token: StringOptional. A token identifying a page of results the server should return.
Implementations
Sourceimpl SearchGrantsRequest
impl SearchGrantsRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_caller_relationship<T: Into<CallerRelationshipType>>(
self,
v: T,
) -> Self
pub fn set_caller_relationship<T: Into<CallerRelationshipType>>( self, v: T, ) -> Self
Sets the value of caller_relationship.
Example
ⓘ
use google_cloud_privilegedaccessmanager_v1::model::search_grants_request::CallerRelationshipType;
let x0 = SearchGrantsRequest::new().set_caller_relationship(CallerRelationshipType::HadCreated);
let x1 = SearchGrantsRequest::new().set_caller_relationship(CallerRelationshipType::CanApprove);
let x2 = SearchGrantsRequest::new().set_caller_relationship(CallerRelationshipType::HadApproved);Sourcepub fn set_filter<T: Into<String>>(self, v: T) -> Self
pub fn set_filter<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
ⓘ
let x = SearchGrantsRequest::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for SearchGrantsRequest
impl Clone for SearchGrantsRequest
Sourcefn clone(&self) -> SearchGrantsRequest
fn clone(&self) -> SearchGrantsRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SearchGrantsRequest
impl Debug for SearchGrantsRequest
Sourceimpl Default for SearchGrantsRequest
impl Default for SearchGrantsRequest
Sourcefn default() -> SearchGrantsRequest
fn default() -> SearchGrantsRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for SearchGrantsRequest
impl Message for SearchGrantsRequest
Sourceimpl PartialEq for SearchGrantsRequest
impl PartialEq for SearchGrantsRequest
impl StructuralPartialEq for SearchGrantsRequest