UpdateEntitlementRequest

Struct UpdateEntitlementRequest 

#[non_exhaustive]
pub struct UpdateEntitlementRequest { pub entitlement: Option<Entitlement>, pub update_mask: Option<FieldMask>, /* private fields */ }
Message for updating an entitlement.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
entitlement: Option<Entitlement>

Required. The entitlement resource that is updated.

update_mask: Option<FieldMask>

Required. The list of fields to update. A field is overwritten if, and only if, it is in the mask. Any immutable fields set in the mask are ignored by the server. Repeated fields and map fields are only allowed in the last position of a paths string and overwrite the existing values. Hence an update to a repeated field or a map should contain the entire list of values. The fields specified in the update_mask are relative to the resource and not to the request. (e.g. MaxRequestDuration; not entitlement.MaxRequestDuration) A value of ‘*’ for this field refers to full replacement of the resource.

Implementations

Source

impl UpdateEntitlementRequest

pub fn new() -> Self

Creates a new default instance.

pub fn set_entitlement<T>(self, v: T) -> Self
where T: Into<Entitlement>,

Sets the value of entitlement.

Example
use google_cloud_privilegedaccessmanager_v1::model::Entitlement;
let x = UpdateEntitlementRequest::new().set_entitlement(Entitlement::default()/* use setters */);
pub fn set_or_clear_entitlement<T>(self, v: Option<T>) -> Self
where T: Into<Entitlement>,

Sets or clears the value of entitlement.

Example
use google_cloud_privilegedaccessmanager_v1::model::Entitlement;
let x = UpdateEntitlementRequest::new().set_or_clear_entitlement(Some(Entitlement::default()/* use setters */));
let x = UpdateEntitlementRequest::new().set_or_clear_entitlement(None::<Entitlement>);
pub fn set_update_mask<T>(self, v: T) -> Self
where T: Into<FieldMask>,

Sets the value of update_mask.

Example
use wkt::FieldMask;
let x = UpdateEntitlementRequest::new().set_update_mask(FieldMask::default()/* use setters */);
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
where T: Into<FieldMask>,

Sets or clears the value of update_mask.

Example
use wkt::FieldMask;
let x = UpdateEntitlementRequest::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = UpdateEntitlementRequest::new().set_or_clear_update_mask(None::<FieldMask>);